#
# spec file for package clusterssh
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define dullver 4.18
Name:           clusterssh
Version:        4.18
Release:        1.4
Summary:        Multiplex SSH sessions onto many hosts using multiple terminals
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Productivity/Networking/SSH
URL:            https://github.com/duncs/clusterssh/wiki
Source:         https://github.com/duncs/clusterssh/archive/v%{dullver}.tar.gz
Source2:        %{name}-rpmlintrc
Patch1:         perl_shebang.patch
BuildRequires:  fdupes
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(CPAN::Changes)
BuildRequires:  perl(Exception::Class)
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  perl(File::Path)
BuildRequires:  perl(File::Slurp)
BuildRequires:  perl(File::Temp)
BuildRequires:  perl(File::Which)
BuildRequires:  perl(Getopt::Long)
BuildRequires:  perl(Locale::Maketext)
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Readonly)
BuildRequires:  perl(Sort::Naturally)
BuildRequires:  perl(Test::Differences)
BuildRequires:  perl(Test::Trap)
BuildRequires:  perl(Tk)
BuildRequires:  perl(Try::Tiny)
BuildRequires:  perl(X11::Protocol)
BuildRequires:  perl(X11::Protocol::WM)
# Test::PerlTidy not available atm
Requires:       perl(Test::PerlTidy)
Requires:       xorg-x11-fonts-100dpi
Requires:       xorg-x11-fonts-75dpi
Requires:       xterm
Requires:       perl(CPAN::Changes)
Requires:       perl(Carp)
Requires:       perl(English)
Requires:       perl(Exception::Class)
Requires:       perl(Fcntl)
Requires:       perl(File::Basename)
Requires:       perl(File::Path)
Requires:       perl(File::Slurp)
Requires:       perl(File::Temp)
Requires:       perl(File::Which)
Requires:       perl(FindBin)
Requires:       perl(Getopt::Long)
Requires:       perl(Locale::Maketext)
Requires:       perl(Module::Build)
Requires:       perl(Net::hostent)
Requires:       perl(POSIX)
Requires:       perl(Pod::Usage)
Requires:       perl(Readonly)
Requires:       perl(Socket)
Requires:       perl(Sort::Naturally)
Requires:       perl(Sys::Hostname)
Requires:       perl(Test::Differences)
Requires:       perl(Test::Pod)
Requires:       perl(Test::Pod::Coverage)
Requires:       perl(Test::Trap)
Requires:       perl(Tk)
Requires:       perl(Tk::ROText)
Requires:       perl(Tk::Xlib)
Requires:       perl(Try::Tiny)
Requires:       perl(X11::Keysyms)
Requires:       perl(X11::Protocol)
Requires:       perl(X11::Protocol::Constants)
Requires:       perl(X11::Protocol::WM)
BuildArch:      noarch
%{perl_requires}

%description
Cluster SSH opens terminal windows with connections to specified
hosts and an administration console. Any text typed into the
administration console is replicated to all other connected and
active windows. This tool is intended for, but not limited to,
cluster administration where the same configuration or commands must
be run on each node within the cluster. Performing these commands all
at once via this tool ensures all nodes are kept in sync.

%prep
%autosetup -n %{name}-%{dullver} -p1

%build
perl Build.PL installdirs=vendor
./Build

%check
# rm t/changes.t

# Readme is not in the tarball
# couldn't open README for reading: No such file or directory at t/boilerplate.t line 9.
rm t/boilerplate.t

./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

install -D -m 0644 %{buildroot}/%{_bindir}/clusterssh_bash_completion.dist \
        %{buildroot}/%{_datadir}/bash-completion/completions/clusterssh
rm %{buildroot}/%{_bindir}/clusterssh_bash_completion.dist

%files
%doc AUTHORS Changes THANKS TODO
%{_bindir}/c*
%{_datadir}/bash-completion/
%{_mandir}/man1/*
%{_mandir}/man3/*
%{perl_vendorlib}/*

%changelog
* Sat Jan 25 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to new upstream release v4.18
  * Re-release due to poor release upload to CPAN
- Update to new upstream release v4.17
  * Swap the hostname lookup macro from DNS to using the system hostname
  * Swap from using Travis-CI to Github Actions
  * Fix tests on perl 5.38 and 5.40
- Drop 150.patch as already included in upstream
- ran spec-cleaner
* Tue Aug  8 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add 150.patch: Fix build with Perl 5.38.
* Mon Jun 22 2020 Michael Ströder <michael@stroeder.com>
- Update to new upstream release v4.16
  * Further fix for 'resolve_names' error when adding hosts via the UI
  * Fix missing space separator for ssh_args (thanks to Petr Vorel)
- removed obsolete backport patch
  0001-helper-Fix-missing-space-separator-for-ssh_args.patch
* Tue May 26 2020 Petr Vorel <pvorel@suse.cz>
- Backport fix for #133
  https://github.com/duncs/clusterssh/pull/133
  0001-helper-Fix-missing-space-separator-for-ssh_args.patch
* Mon May 18 2020 Michael Ströder <michael@stroeder.com>
- Update to new upstream release v4.15
  * Include all utilies within each man page
  * Add in 'command_pre' and 'command_post' configuration options
  * Fix 'Add Host' menu error finding 'resolved_names'
  * Ensure lib path is added to range tests to find the libraries
  * Mark permission test as TODO as it appears to be inconsistent
* Thu Aug 22 2019 Michael Ströder <michael@stroeder.com>
- Update to new upstream release v4.14
  * Include README within the repository, not just created tar.gz files
  * Add 'autoquit' setting to 'File' menu (Github issue #114)
  * Correct macro_hostname to be the FQDN of the server where
    cssh is being run (Github issue #116)
  * Add in user defined macros
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Own entire bash-completion subtree
* Sat Mar 16 2019 Petr Vorel <petr.vorel@gmail.com>
- Update to new upstream release v4.13.2_02
  https://github.com/duncs/clusterssh/blob/v4.13.2_02/Changes
- Drop clusterssh-fix-docgen.patch as it has been fixed upstream
  (https://github.com/duncs/clusterssh/pull/106)
- Add new dependency X11::Protocol::WM (build and runtime)
- Drop clusterssh-fix-docgen.patch (not relevant any more)
- Add patch fixing shebang (perl_shebang.patch)
- Disable Test::PerlTidy as it's not available
- Add new build and runtime dependency X11::Protocol::WM
- Add new build dependency Test::Trap (for testing)
* Sat Mar  3 2018 bwiedemann@suse.com
- Add clusterssh-fix-docgen.patch to fix doc generation race
  (boo#1083835)
* Fri Jan 20 2017 rmaliska@suse.com
- Update to new upstream release 4.07
  * Fixed tests on systems where bash is not installed in /bin/bash
  (Github issue #60)
  * Include link to travis-ci site in release emails for automated
  build and test reports
  * Rework hostname expansion to be pure-perl rather than relying on
  the bash shell (Github issue #53)
  For further changes of previous updates see:
  https://github.com/duncs/clusterssh/blob/master/Changes
* Wed Jan 27 2016 darin@darins.net
- Added patch remove-time-key.patch, which resolves the issue where
  windows become unmoveable after executing cssh in KDE5.
  See for bnc#956316 and https://github.com/duncs/clusterssh/issues/46
* Fri Jun 28 2013 jengelh@inai.de
- Update to new upstream release 4.02.01
  * New option (-m, --unique-servers) to remove repeated servers when
  opening terminals
* Sun Mar  3 2013 jengelh@inai.de
- Update to new upstream release 4.01.03
  * Allow the path to rsh/ssh/telnet to be defined in the
  configuration file
  * Move .csshrc to .csshrc.DISABLED since it should no longer be used
  * Resolve error emitted when adding a host via the "Hosts" drop-down
  * Resolve paste using a strange keyboard layout
  * Cope with being invoked by "clusterssh"
  * Remove doc references to "always_tile" (is known as "window_tiling")
  * Updated manpage whatis entries
  * Fix cssh starting if xterm is not installed
  * Set WM_CLASS on windows to "cssh"
* Tue Nov 27 2012 cfarrell@suse.com
- license update: GPL-1.0+ or Artistic-1.0
  See README
* Thu Oct 25 2012 jengelh@inai.de
- Initial package for build.opensuse.org (4.01.01)
